//******************************************************************************
//  F2013_ADS8361.c - USI SPI Interface to ADS8361 16-bit ADC
//
//   Description: This program demonstrates the USI in SPI mode interface to an
//   ADS8361 16-bit ADC.
//
//                          MSP430F2013
//                       -----------------
//                   /|\|              XIN|-
//       ADS8361      | |                 |
//    -------------   --|RST          XOUT|-
//   |           CS|<---|P1.1             |
//   |      DATAOUT|--->|P1.7/SOMI    P1.0|-->/CS - optional
// ~>|AIN   I/O CLK|<---|P1.5/SCLK        |
//
//  T. Hendrick
//  Texas Instruments Inc.
//  June 2006 for AAJ 3Q06
//  IAR Assembler for MSP430 V3.40B/W32 (3.40.2.9)
//******************************************************************************

#include <msp430x20x3.h>
int ADCdata;
void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Stop watchdog timer
  USICTL0 |= USIPE7 +  USIPE6 +  USIPE5 + USIMST + USIOE; // Port, SPI master
  USICTL1 |= USIIE;              // Counter interrupt, flag remains set
  USICKCTL = USISSEL_2;          // USI Clock Selection
  USICTL0 &= ~USISWRST;          // USI released for operation
  _BIS_SR(GIE);                  // Enter LPM0 w/ interrupt
}

// USI interrupt service routine
#pragma vector=USI_VECTOR
__interrupt void universal_serial_interface(void)
{
  USISR = 0x8000;             //  Toggle RD+CONVST to initiate Conversion
  USICNT |= (USI16B + 0x13);  //  Send 19 SCLK cycles
  while(!(USIIFG & USICTL1))  //  Wait for transmission to complete
  {
  ADCdata = USISR;            //  Store data
  USISR = 0x0000;
  }
}

